==> qtjambi-remoteobjects-6.6.0-sources.jar: io/qt/remoteobjects/QtROIoDeviceBase.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QtROIoDeviceBase</code></p>
 */
public abstract class QtROIoDeviceBase extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROIoDeviceBase.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROIoDeviceBase {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected java.lang.@NonNull String deviceType(){
            return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String deviceType_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    

    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>disconnected()</code></p>
     */
    public final @NonNull Signal0 disconnected = new Signal0();

    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>readyRead()</code></p>
     */
    public final @NonNull Signal0 readyRead = new Signal0();
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>QtROIoDeviceBase(QObject*)</code></p>
     */
    public QtROIoDeviceBase(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROIoDeviceBase instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>addSource(QString)</code></p>
     */
    @QtUninvokable
    public final void addSource(java.lang.@NonNull String arg__1){
        addSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void addSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>initializeDataStream()</code></p>
     */
    @QtUninvokable
    public final void initializeDataStream(){
        initializeDataStream_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void initializeDataStream_native(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>isClosing()const</code></p>
     */
    @QtUninvokable
    public final boolean isClosing(){
        return isClosing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isClosing_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>read(QtRemoteObjects::QRemoteObjectPacketTypeEnum&amp;,<wbr>QString&amp;)</code></p>
     */
    @QtUninvokable
    public final io.qt.remoteobjects.QtROIoDeviceBase.@Nullable ReadResult read(){
        return read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.remoteobjects.QtROIoDeviceBase.@Nullable ReadResult read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>remoteObjects()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QSet<java.lang.@NonNull String> remoteObjects(){
        return remoteObjects_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QSet<java.lang.String> remoteObjects_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>removeSource(QString)</code></p>
     */
    @QtUninvokable
    public final void removeSource(java.lang.@NonNull String arg__1){
        removeSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void removeSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>bytesAvailable()const</code></p>
     */
    @QtUninvokable
    public long bytesAvailable(){
        return bytesAvailable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long bytesAvailable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>close()</code></p>
     */
    @QtUninvokable
    public void close(){
        close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void close_native(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>connection()const</code></p>
     */
    @QtUninvokable
    public abstract io.qt.core.@Nullable QIODevice connection();
    
    @QtUninvokable
    private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>deviceType()const</code></p>
     */
    @QtUninvokable
    protected abstract java.lang.@NonNull String deviceType();
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>doClose()</code></p>
     */
    @QtUninvokable
    protected abstract void doClose();
    
    @QtUninvokable
    private native void doClose_native(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>isOpen()const</code></p>
     */
    @QtUninvokable
    public boolean isOpen(){
        return isOpen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOpen_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>write(QByteArray)</code></p>
     */
    @QtUninvokable
    public void write(io.qt.core.@NonNull QByteArray data){
        write_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @QtUninvokable
    private native void write_native_cref_QByteArray(long __this__nativeId, long data);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>write(QByteArray,<wbr>qint64)</code></p>
     */
    @QtUninvokable
    public void write(io.qt.core.@NonNull QByteArray data, long arg__2){
        write_native_cref_QByteArray_qint64(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data), arg__2);
    }
    
    @QtUninvokable
    private native void write_native_cref_QByteArray_qint64(long __this__nativeId, long data, long arg__2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QtROIoDeviceBase(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QtROIoDeviceBase(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROIoDeviceBase instance, QDeclarativeConstructor constructor);
    
    public class ReadResult{
        public final QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType;
        public final String result;
        
        private ReadResult(QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType, String result) {
            super();
            this.packetType = packetType;
            this.result = result;
        }
    }
    
    /**
     * <p>Overloaded constructor for {@link #QtROIoDeviceBase(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROIoDeviceBase() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-remoteobjects-6.7.1-sources.jar: io/qt/remoteobjects/QtROIoDeviceBase.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QtROIoDeviceBase</code></p>
 */
public abstract class QtROIoDeviceBase extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROIoDeviceBase.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROIoDeviceBase {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected java.lang.@NonNull String deviceType(){
            return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String deviceType_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    

    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>disconnected()</code></p>
     */
    public final @NonNull Signal0 disconnected = new Signal0();

    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>readyRead()</code></p>
     */
    public final @NonNull Signal0 readyRead = new Signal0();
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>QtROIoDeviceBase(QObject*)</code></p>
     */
    public QtROIoDeviceBase(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROIoDeviceBase instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>addSource(QString)</code></p>
     */
    @QtUninvokable
    public final void addSource(java.lang.@NonNull String arg__1){
        addSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void addSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>initializeDataStream()</code></p>
     */
    @QtUninvokable
    public final void initializeDataStream(){
        initializeDataStream_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void initializeDataStream_native(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>isClosing()const</code></p>
     */
    @QtUninvokable
    public final boolean isClosing(){
        return isClosing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isClosing_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>read(QtRemoteObjects::QRemoteObjectPacketTypeEnum&amp;,<wbr/>QString&amp;)</code></p>
     */
    @QtUninvokable
    public final io.qt.remoteobjects.QtROIoDeviceBase.@Nullable ReadResult read(){
        return read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.remoteobjects.QtROIoDeviceBase.@Nullable ReadResult read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>remoteObjects()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QSet<java.lang.@NonNull String> remoteObjects(){
        return remoteObjects_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QSet<java.lang.String> remoteObjects_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>removeSource(QString)</code></p>
     */
    @QtUninvokable
    public final void removeSource(java.lang.@NonNull String arg__1){
        removeSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void removeSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>bytesAvailable()const</code></p>
     */
    @QtUninvokable
    public long bytesAvailable(){
        return bytesAvailable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long bytesAvailable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>close()</code></p>
     */
    @QtUninvokable
    public void close(){
        close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void close_native(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>connection()const</code></p>
     */
    @QtUninvokable
    public abstract io.qt.core.@Nullable QIODevice connection();
    
    @QtUninvokable
    private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>deviceType()const</code></p>
     */
    @QtUninvokable
    protected abstract java.lang.@NonNull String deviceType();
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>doClose()</code></p>
     */
    @QtUninvokable
    protected abstract void doClose();
    
    @QtUninvokable
    private native void doClose_native(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>isOpen()const</code></p>
     */
    @QtUninvokable
    public boolean isOpen(){
        return isOpen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOpen_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>write(QByteArray)</code></p>
     */
    @QtUninvokable
    public void write(io.qt.core.@NonNull QByteArray data){
        write_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @QtUninvokable
    private native void write_native_cref_QByteArray(long __this__nativeId, long data);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr/>write(QByteArray,<wbr/>qint64)</code></p>
     */
    @QtUninvokable
    public void write(io.qt.core.@NonNull QByteArray data, long arg__2){
        write_native_cref_QByteArray_qint64(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data), arg__2);
    }
    
    @QtUninvokable
    private native void write_native_cref_QByteArray_qint64(long __this__nativeId, long data, long arg__2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QtROIoDeviceBase(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QtROIoDeviceBase(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROIoDeviceBase instance, QDeclarativeConstructor constructor);
    
    public class ReadResult{
        public final QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType;
        public final String result;
        
        private ReadResult(QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType, String result) {
            super();
            this.packetType = packetType;
            this.result = result;
        }
    }
    
    /**
     * <p>Overloaded constructor for {@link #QtROIoDeviceBase(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROIoDeviceBase() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QByteArray)}.</p>
     */
    @QtUninvokable
    public final void write(byte @NonNull[] data) {
        write(new io.qt.core.QByteArray(data));
    }
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QByteArray, long)}.</p>
     */
    @QtUninvokable
    public final void write(byte @NonNull[] data, long arg__2) {
        write(new io.qt.core.QByteArray(data), arg__2);
    }
}
